Fix macOS build (#996)

* Fix macOS build. See https://github.com/WebAssembly/binaryen/issues/4299

* Update comment
diff --git a/emsdk.py b/emsdk.py
index 24ed1e9..fe0c11a 100644
--- a/emsdk.py
+++ b/emsdk.py
@@ -1033,16 +1033,16 @@
       generator = []
 
     cmdline = ['cmake'] + generator + ['-DCMAKE_BUILD_TYPE=' + build_type, '-DPYTHON_EXECUTABLE=' + sys.executable]
-    # Target macOS 10.11 at minimum, to support widest range of Mac devices from "Mid 2007" and newer:
-    # https://en.wikipedia.org/wiki/MacBook_Pro#Supported_macOS_releases
-    cmdline += ['-DCMAKE_OSX_DEPLOYMENT_TARGET=10.11']
+    # Target macOS 10.14 at minimum, to support widest range of Mac devices from "Early 2008" and newer:
+    # https://en.wikipedia.org/wiki/MacBook_(2006–2012)#Supported_operating_systems
+    cmdline += ['-DCMAKE_OSX_DEPLOYMENT_TARGET=10.14']
     cmdline += extra_cmake_args + [src_root]
 
     print('Running CMake: ' + str(cmdline))
 
     # Specify the deployment target also as an env. var, since some Xcode versions
     # read this instead of the CMake field.
-    os.environ['MACOSX_DEPLOYMENT_TARGET'] = '10.11'
+    os.environ['MACOSX_DEPLOYMENT_TARGET'] = '10.14'
 
     def quote_parens(x):
       if ' ' in x: